def validate(payload, data):
    """Dummy validator.

    :param payload: payload to validate
    :param data: dictionary with the key ``message``
    """

    if payload == data['message']:
        return (True, 'Payload validated')
    else:
        return (False, 'Payload validation failed')


from distutils.core import setup

setup(
    name='sloth-ci',
    version='0.2.5',
    author='Konstantin Molchanov',
    description='CI for humans',
    long_description='Sloth is a simple script to perform push-based actions.',
    author_email='moigagoo@myopera.com',
    url='https://bitbucket.org/moigagoo/sloth-ci',
    packages=[
        'sloth_ci',
        'sloth_ci.validators'
    ],
    install_requires = [
        'CherryPy',
        'requests',
        'configs>=2.0.5'
    ],
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3'],
    entry_points={
        'console_scripts':
            ['sloth-ci-start = sloth_ci.api:main']
        }
    )



def validate(payload, data):
    """Validate Bitbucket payload against repo name and branch (obtained from the Sloth instance config.)

    :param payload: payload to validate
    :param data: dictionary with the keys ``repo`` (in form "??username/repo"??) and ``branch``

    :returns: (True, success message) of the payload is valid, (False, error message) otherwise
    """

    from json import loads

    try:
        parsed_payload = loads(payload)

        repo = parsed_payload['repository']['owner'] + '/' + parsed_payload['repository']['slug']
        branch = parsed_payload['commits'][-1]['branch']

        if repo == data['repo'] and branch == data['branch']:
            return (True, 'Payload validated')
        elif repo != data['repo']:
            return (False, 'Payload validation failed: repo mismatch')
        elif branch != data['branch']:
            return (False, 'Payload validation failed: branch mismatch')
    except Exception as e:
        return (False, 'Payload validation failed: %s' % e)